SoapySDR_getModuleVersion

Function SoapySDR_getModuleVersion 

pub unsafe extern "C" fn SoapySDR_getModuleVersion(
    path: *const c_char,
) -> *mut c_char
Get a version string for the specified module.

Modules may optionally provide version strings. \param path the path to a specific module file \return a version string or empty if no version provided