SoapySDR_loadModule

Function SoapySDR_loadModule 

pub unsafe extern "C" fn SoapySDR_loadModule(
    path: *const c_char,
) -> *mut c_char
Load a single module given its file system path.

The caller must free the result error string. \param path the path to a specific module file \return an error message, empty on success